#
# spec file for package ghc-hashable
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hashable
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.7.0
Release:        lp151.1.2
Summary:        A class for types that can be converted to a hash value
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-unix-devel
%endif

%description
This package defines a class, 'Hashable', for types that can be converted to a
hash value. This class exists for the benefit of hashing-based data structures.
The package provides instances for basic types and a way to combine hash
values.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ifarch i586
%define cabal_configure_options -f"-sse2"
%endif
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.md README.md

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to support GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update hashable to version 1.2.7.0.
  * Add `Hashable` and `Hashable1` instances for `Complex`
  * Fix undefined behavior in `hashable_fn_hash()` implementation
  due to signed integer overflow (#152)
  * Mark `Data.Hashable.Lifted` as `Trustworthy` (re SafeHaskell)
  * Support GHC 8.4
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sat Jul  8 2017 psimons@suse.com
- Update to version 1.2.6.1 revision 2.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 1.2.6.1 revision 1.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 1.2.6.0 revision 1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.2.5.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.4.0 revision 0 with cabal2obs.
* Sun Jan 17 2016 mimi.vx@gmail.com
- update to 1.2.4.0
  * Add instances for: Unique, Version, Fixed, NonEmpty, Min, Max, Arg,
    First, Last, WrappedMonoid, Option
* Sun Jun 28 2015 mimi.vx@gmail.com
- update to 1.2.3.3
  * Support integer-simple.
* Sun Apr 12 2015 mimi.vx@gmail.com
- update to 1.2.3.2
  + disable SSE2 on i586 arch
  * Add support for GHC 7.10 typeRepFingerprint
  * Added support for random 1.1.*.
  * Silence integer literal overflow warning
  * Add support for GHC 7.10 `integer-gmp2` & `Natural`
  * Add instance for Data.Void
  * Make the SSE .cabal flags manual
  * Add an upper bound on bytestring
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 1.2.2.0
  * several performance fixes including use of SSE and SSE2
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 1.1.2.5 from upstream
  * changelog not updated since 1.1.1.0
- version required for Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Thu Jun  7 2012 herbert@graeber-clan.de
- update to version 1.1.2.3
  spec file template generated by cabal2spec-0.25.5
* Sun Feb  5 2012 herbert@graeber-clan.de
- Initial package
